@@ -7,19 +7,23 @@ require LinkEmbedder;
 
 # please report back if you add more urls to this hash
 our %API = (
-  'instagram.com' => 'https://api.instagram.com/oembed',
+  'instagram.com' => 'https://api.instagram.com/oembed?omitscript=1',
   'ted.com'       => 'https://www.ted.com/services/v1/oembed.json',
   'vimeo.com'     => 'https://vimeo.com/api/oembed.json',
   'youtube.com'   => 'https://www.youtube.com/oembed',
 );
 
-has html => sub { shift->html };
+has html => sub { shift->SUPER::html };
 
 sub learn {
   my ($self, $cb) = @_;
-  my $api_url = $self->_api_url;
 
-  if (!$api_url) {
+  unless ($self->url->path =~ /\w/) {
+    return $self->SUPER::learn($cb);
+  }
+
+  my $api_url = $self->_api_url;
+  unless ($api_url) {
     $self->error({message => "Unknown oEmbed provider for @{[$self->url]}", code => 400});
     $self->$cb if $cb;
     return $self;
